@@ -20,6 +20,7 @@
 #pragma once
 #include <src/global/global.h>
 #include <src/machine/elements/valeur/position_instruction.h>
+#include <src/machine/interface/variable.h>
 
 
 namespace SVM
@@ -37,11 +38,12 @@ namespace SVM_Extension = SVM::Machine::Extension;
 	struct Decorateur
 	{
 		Decorateur(const CodeSP& code, const SVM::Machine::MachineSP& machine, const bool remplacement=false)
-		:_code(code), _machine(machine),_remplacement(remplacement) {}
+		:_code(code), _machine(machine),_remplacement(remplacement), _cache_variables(std::make_shared<SVM::Machine::Interface::CacheEnsembleVariables>()) {}
 		const CodeSP _code;
 		const SVM::Machine::MachineSP _machine;
 		const bool _remplacement;
 		SVM_Valeur::PositionInstructionSP _position;
+		SHARED_PTR(SVM::Machine::Interface::CacheEnsembleVariables) _cache_variables;
 	};
 }
 }
