@@ -1066,58 +1066,99 @@ ConfigurationPaquet::ConfigurationPaquet()
 	}
 }
 
-void ConfigurationPaquet::modifie(const AttributPaquet& a, const size_t position)
+void ConfigurationPaquet::modifie(const AttributPaquet& a)
 {
 	const auto& configuration = ConfigurationPaquet::configuration();
 	auto cfg = configuration.find(a._nom)->second;
-	std::vector<ValeurOptionSP> valeurs;
+	std::vector<ValeurOptionConstanteSP> valeurs;
 	for(size_t i=0 ; i<a._valeurs.size() ; ++i)
 	{
-		auto valeur = a._valeurs[i];
-		while(valeur->type()==ValeurOption::Type::VARIABLE)
+		try
 		{
-			ValeurOptionVariableSP var = std::static_pointer_cast<ValeurOptionVariable>(valeur);
-			auto itv = _variables.find(var->_nom);
-			if(itv==_variables.end())
+			auto valeur = a._valeurs[i]->evaluation(*this);
+			if(not ValeurOption::compatible(cfg._types[i],valeur->type()))
 			{
 				std::ostringstream oss;
-				oss << "Variable " << var->_nom << " at position " << (i+1) << " does not exist.";
-				Erreur e(oss.str());
-				e.position(position,position);
-				throw e;
-			}
-			auto v = itv->second;
-			if(v->type()==ValeurOption::Type::DEFAUT)
-			{
-				v = cfg._defaut[i];
-			}
-			if(not ValeurOption::compatible(cfg._types[i],v->type()))
-			{
-				std::ostringstream oss;
-				oss << "Variable " << var->_nom << " at position " << (i+1) << " has a value of type " << ValeurOption::type(v->type()) << " instead of one among [";
+				oss << "Value at position " << (i+1) << " has a value of type " << ValeurOption::type(valeur->type()) << " instead of one among [";
 				for(const auto&t : cfg._types[i])
 				{
 					oss << " " << ValeurOption::type(t);
 				}
 				oss << " ].";
 				Erreur e(oss.str());
-				e.position(position,position);
 				throw e;
 			}
-			valeur = v;
+			if(valeur->type()==ValeurOption::Type::DEFAUT)
+			{
+				valeurs.push_back(cfg._defaut[i]);
+			}
+			else
+			{
+				valeurs.push_back(valeur);
+			}
 		}
-		if(valeur->type()==ValeurOption::Type::DEFAUT)
+		catch(Erreur& pe)
 		{
-			valeurs.push_back(cfg._defaut[i]);
-		}
-		else
-		{
-			valeurs.push_back(valeur);
+			std::ostringstream oss;
+			oss << "Value at position " << (i+1) << " can not be evaluated: " << pe.message();
+			Erreur e(oss.str());
+			throw e;
 		}
 	}
 	_etat[a._nom] = valeurs;
 }
 
+std::string ValeurOption::evaluation_chaine(ConfigurationPaquet& configuration) const
+{
+	try
+	{
+		ValeurOptionConstanteSP c = evaluation(configuration);
+		return c->evaluation_chaine();
+	}
+	catch(Erreur& e)
+	{
+		return std::string();
+	}
+}
+
+bool ValeurOption::evaluation_booleene(ConfigurationPaquet& configuration) const
+{
+	try
+	{
+		ValeurOptionConstanteSP c = evaluation(configuration);
+		return c->evaluation_booleene();
+	}
+	catch(Erreur& e)
+	{
+		return false;
+	}
+}
+
+ValeurOptionConstanteSP ValeurOptionVariable::evaluation(ConfigurationPaquet& configuration) const
+{
+	auto itv = configuration._variables.find(_nom);
+	if(itv==configuration._variables.end())
+	{
+		std::ostringstream oss;
+		oss << "Variable " << _nom << " does not exist.";
+		Erreur e(oss.str());
+		throw e;
+	}
+	return itv->second->evaluation(configuration);
+}
+
+ValeurOptionConstanteSP ValeurOptionConcatenation::evaluation(ConfigurationPaquet& configuration) const
+{
+	return std::make_shared<ValeurOptionChaine>(_gauche->evaluation_chaine(configuration)+_droite->evaluation_chaine(configuration));
+}
+
+bool PaquetConditionVariable::evaluation(ConfigurationPaquet& configuration) const
+{
+	auto itv = configuration._variables.find(_nom);
+	if(itv==configuration._variables.end()) return false;
+	return itv->second->evaluation_booleene();
+}
+
 ValeurOptionSP ConfigurationPaquet::lit(const std::string& nom, const size_t indice_valeur) const
 {
 	auto ic = _etat.find(nom);
@@ -1149,7 +1190,25 @@ bool ConfigurationPaquet::lit_booleen(const std::string& nom, const size_t indic
 
 void ConfigurationPaquet::variable(const AttributPaquet& a)
 {
-	_variables[a._nom] = a._valeurs[0];
+	_variables[a._nom] = a._valeurs[0]->evaluation(*this);
+}
+
+void ConfigurationPaquet::drapeaux(const std::set<std::string>& drapeaux, const std::set<std::string>& drapeaux_leves)
+{
+	for(const auto& d: drapeaux)
+	{
+		variable(AttributPaquet (d,{std::make_shared<ValeurOptionBooleen>(false)}));
+	}
+	for(const auto& d: drapeaux_leves)
+	{
+		variable(AttributPaquet (d,{std::make_shared<ValeurOptionBooleen>(true)}));
+	}
+}
+void ConfigurationPaquet::variables_automatiques(const bool debug, const std::string& saveur)
+{
+	variable(AttributPaquet ("only_in_dev",{std::make_shared<ValeurOptionBooleen>(debug)}));
+	variable(AttributPaquet ("only_in_release",{std::make_shared<ValeurOptionBooleen>(not debug)}));
+	variable(AttributPaquet ("package_flavor",{std::make_shared<ValeurOptionChaine>(saveur)}));
 }
 
 void AttributPaquet::verification(const std::string& type, const size_t position) const
@@ -1236,7 +1295,15 @@ void ContenuPaquetConfiguration::verification()
 
 void OptionPaquet::construction(ConfigurationPaquet& configuration)
 {
-	configuration.modifie(*this,_position);
+	try
+	{
+		configuration.modifie(*this);
+	}
+	catch(Erreur& e)
+	{
+		e.position(_position,_position);
+		throw;
+	}
 }
 
 void FichierPaquet::construction(ConfigurationPaquet& configuration, const size_t position)
@@ -1252,6 +1319,18 @@ void FichierPaquet::construction(ConfigurationPaquet& configuration, const size_
 	}
 	_fin_de_fichier = configuration.lit_chaine("end_of_file",0);
 	_destination = _chemin + "/$(basename " + _nom + ")";
+	std::string destination = _chemin + "/" ;
+	size_t s = _nom.find_last_of('/');
+	if(s==std::string::npos) s=0;
+	destination += _nom.substr(s,_nom.size()-s);
+	if(not configuration._fichiers.insert(destination).second)
+	{
+		std::ostringstream oss;
+		oss << "File " << destination << " is already created within the package.";
+		Erreur e(oss.str());
+		e.position(position,position);
+		throw e;
+	}
 }
 
 void ContenuPaquetApplication::construction(ConfigurationPaquet& configuration)
@@ -1259,11 +1338,13 @@ void ContenuPaquetApplication::construction(ConfigurationPaquet& configuration)
 	FichierPaquet::construction(configuration,_position);
 	_changer_interpreteur = configuration.lit_booleen("app_change_sheebang",0);
 	_racine_extensions_locales = configuration.lit_chaine("app_local_plugins_root",0);
+	_condition = configuration._condition;
 }
 
 void ContenuPaquetBibliotheque::construction(ConfigurationPaquet& configuration)
 {
 	FichierPaquet::construction(configuration,_position);
+	_condition = configuration._condition;
 }
 
 void ContenuPaquetExtension::construction(ConfigurationPaquet& configuration)
@@ -1273,26 +1354,50 @@ void ContenuPaquetExtension::construction(ConfigurationPaquet& configuration)
 	_garde_construction = configuration.lit_booleen("plugin_keep_build",0);
 	_joue_tests = configuration.lit_booleen("plugin_check",0);
 	_enleve_source = configuration.lit_booleen("plugin_remove_source",0);
+	_condition = configuration._condition;
 }
 
 void ContenuPaquetFichier::construction(ConfigurationPaquet& configuration)
 {
 	FichierPaquet::construction(configuration,_position);
 	_mode = configuration.lit_chaine("file_mode",0);
+	_condition = configuration._condition;
 }
 
 void ContenuPaquetConfiguration::construction(ConfigurationPaquet& configuration)
 {
-	configuration.modifie(*this,_position);
+	_condition = configuration._condition;
+	if(not _condition) return;
+	try
+	{
+		configuration.modifie(*this);
+	}
+	catch(Erreur& e)
+	{
+		e.position(_position,_position);
+		throw;
+	}
 }
 
 void ContenuPaquetVariable::construction(ConfigurationPaquet& configuration)
 {
-	configuration.variable(*this);
+	_condition = configuration._condition;
+	if(not _condition) return;
+	try
+	{
+		configuration.variable(*this);
+	}
+	catch(Erreur& e)
+	{
+		e.position(_position,_position);
+		throw;
+	}
 }
 
 void ContenuPaquetCode::construction(ConfigurationPaquet& configuration)
 {
+	_condition = configuration._condition;
+	_variables = configuration._variables;
 }
 
 void FichierPaquet::generation(std::ostream& os)
@@ -1309,6 +1414,7 @@ void FichierPaquet::generation(std::ostream& os)
 
 void ContenuPaquetApplication::generation(std::ostream& os)
 {
+	if(not _condition) return;
 	FichierPaquet::generation(os);
 	os	<< "chmod u+x " << _destination << std::endl;
 	if(_changer_interpreteur)
@@ -1323,11 +1429,13 @@ void ContenuPaquetApplication::generation(std::ostream& os)
 
 void ContenuPaquetBibliotheque::generation(std::ostream& os)
 {
+	if(not _condition) return;
 	FichierPaquet::generation(os);
 }
 
 void ContenuPaquetExtension::generation(std::ostream& os)
 {
+	if(not _condition) return;
 	FichierPaquet::generation(os);
 	if(_installation)
 	{
@@ -1361,6 +1469,7 @@ void ContenuPaquetExtension::generation(std::ostream& os)
 
 void ContenuPaquetFichier::generation(std::ostream& os)
 {
+	if(not _condition) return;
 	FichierPaquet::generation(os);
 	if(not _mode.empty())
 	{
@@ -1373,8 +1482,13 @@ void ContenuPaquetFichier::generation(std::ostream& os)
 
 void ContenuPaquetCode::generation(std::ostream& os)
 {
-	os	<< "(" << std::endl
-		<< _code << ")" << std::endl;
+	if(not _condition) return;
+	os	<< "(" << std::endl;
+	for(const auto& v: _variables)
+	{
+		os	<< "export " << v.first << "=" << (*v.second) << std::endl;
+	}
+	os	<< _code << ")" << std::endl;
 }
 
 void Paquet::verification()
@@ -1389,12 +1503,24 @@ void Paquet::verification()
 	}
 }
 
-void Paquet::construction(const bool debug)
+void Paquet::construction(const std::string& saveur, const bool debug, std::set<std::string>& drapeaux)
 {
+	if(not saveur.empty())
+	{
+		if(saveur.find('/')!=std::string::npos)
+		{
+			std::ostringstream oss;
+			oss << "Invalid flavor " << saveur << ".";
+			throw Erreur(oss.str());
+		}
+		_nom += "-" + saveur;
+		drapeaux.insert(saveur);
+	}
+	_saveur = saveur;
 	_debug = debug;
 	ConfigurationPaquet configuration;
-	configuration.variable(AttributPaquet ("only_in_dev",{std::make_shared<ValeurOptionBooleen>(debug)}));
-	configuration.variable(AttributPaquet ("only_in_release",{std::make_shared<ValeurOptionBooleen>(not debug)}));
+	configuration.drapeaux(_drapeaux,drapeaux);
+	configuration.variables_automatiques(debug,saveur);
 	for(auto o: _options)
 	{
 		o->construction(configuration);
